[![](https://img.shields.io/github/release/mueslo/mbs.svg?style=flat-square)](https://github.com/mueslo/mbs/releases)
[![](https://img.shields.io/pypi/v/mbs.svg?style=flat-square)](https://pypi.org/project/mbs/)<!--
[![](https://img.shields.io/github/workflow/status/mueslo/mbs/tests.yml?branch=master&style=flat-square)](https://github.com/mueslo/mbs/actions/workflows/tests.yml)-->
[![](https://img.shields.io/readthedocs/mbsutils.svg?style=flat-square)](https://mbsutils.readthedocs.io)
[![](https://img.shields.io/github/license/mueslo/mbs.svg?style=flat-square)](https://github.com/mueslo/mbs/blob/master/LICENSE)


# MBS

Simple Python library for loading and plotting MB Scientific ARPES detector data in both KRX and TXT format.

## Installation

To install using `pip`, simply run `pip install mbs`.

To install using `conda`, please follow [these instructions](https://docs.conda.io/projects/conda/en/latest/user-guide/tasks/manage-pkgs.html#installing-non-conda-packages), as `mbs` is not directly published on `conda` .

## Usage & Documentation

For some simple examples, see [mbs_example.ipynb](examples/mbs_example.ipynb). In case interactive widgets are not showing up, please follow [this guide](https://ipywidgets.readthedocs.io/en/stable/user_install.html).
Full documentation is still a work in progress will be found [here](https://mbsutils.readthedocs.org).

